MLE_KEY_DEF("F1", 0, 0, TB_KEY_F1)
MLE_KEY_DEF("F2", 0, 0, TB_KEY_F2)
MLE_KEY_DEF("F3", 0, 0, TB_KEY_F3)
MLE_KEY_DEF("F4", 0, 0, TB_KEY_F4)
MLE_KEY_DEF("F5", 0, 0, TB_KEY_F5)
MLE_KEY_DEF("F6", 0, 0, TB_KEY_F6)
MLE_KEY_DEF("F7", 0, 0, TB_KEY_F7)
MLE_KEY_DEF("F8", 0, 0, TB_KEY_F8)
MLE_KEY_DEF("F9", 0, 0, TB_KEY_F9)
MLE_KEY_DEF("F10", 0, 0, TB_KEY_F10)
MLE_KEY_DEF("F11", 0, 0, TB_KEY_F11)
MLE_KEY_DEF("F12", 0, 0, TB_KEY_F12)
MLE_KEY_DEF("insert", 0, 0, TB_KEY_INSERT)
MLE_KEY_DEF("delete", 0, 0, TB_KEY_DELETE)
MLE_KEY_DEF("home", 0, 0, TB_KEY_HOME)
MLE_KEY_DEF("end", 0, 0, TB_KEY_END)
MLE_KEY_DEF("page-up", 0, 0, TB_KEY_PGUP)
MLE_KEY_DEF("page-down", 0, 0, TB_KEY_PGDN)
MLE_KEY_DEF("up", 0, 0, TB_KEY_ARROW_UP)
MLE_KEY_DEF("down", 0, 0, TB_KEY_ARROW_DOWN)
MLE_KEY_DEF("left", 0, 0, TB_KEY_ARROW_LEFT)
MLE_KEY_DEF("right", 0, 0, TB_KEY_ARROW_RIGHT)
MLE_KEY_DEF("C-~", 0, 0, TB_KEY_CTRL_TILDE)
MLE_KEY_DEF("C-2", 0, 0, TB_KEY_CTRL_2)
MLE_KEY_DEF("C-a", 0, 0, TB_KEY_CTRL_A)
MLE_KEY_DEF("C-b", 0, 0, TB_KEY_CTRL_B)
MLE_KEY_DEF("C-c", 0, 0, TB_KEY_CTRL_C)
MLE_KEY_DEF("C-d", 0, 0, TB_KEY_CTRL_D)
MLE_KEY_DEF("C-e", 0, 0, TB_KEY_CTRL_E)
MLE_KEY_DEF("C-f", 0, 0, TB_KEY_CTRL_F)
MLE_KEY_DEF("C-g", 0, 0, TB_KEY_CTRL_G)
MLE_KEY_DEF("backspace", 0, 0, TB_KEY_BACKSPACE)
MLE_KEY_DEF("C-h", 0, 0, TB_KEY_CTRL_H)
MLE_KEY_DEF("tab", 0, 0, TB_KEY_TAB)
MLE_KEY_DEF("C-i", 0, 9, TB_KEY_CTRL_I)
MLE_KEY_DEF("C-j", 0, 0, TB_KEY_CTRL_J)
MLE_KEY_DEF("C-k", 0, 0, TB_KEY_CTRL_K)
MLE_KEY_DEF("C-l", 0, 0, TB_KEY_CTRL_L)
MLE_KEY_DEF("enter", 0, 0, TB_KEY_ENTER)
MLE_KEY_DEF("C-m", 0, 0, TB_KEY_CTRL_M)
MLE_KEY_DEF("C-n", 0, 0, TB_KEY_CTRL_N)
MLE_KEY_DEF("C-o", 0, 0, TB_KEY_CTRL_O)
MLE_KEY_DEF("C-p", 0, 0, TB_KEY_CTRL_P)
MLE_KEY_DEF("C-q", 0, 0, TB_KEY_CTRL_Q)
MLE_KEY_DEF("C-r", 0, 0, TB_KEY_CTRL_R)
MLE_KEY_DEF("C-s", 0, 0, TB_KEY_CTRL_S)
MLE_KEY_DEF("C-t", 0, 0, TB_KEY_CTRL_T)
MLE_KEY_DEF("C-u", 0, 0, TB_KEY_CTRL_U)
MLE_KEY_DEF("C-v", 0, 0, TB_KEY_CTRL_V)
MLE_KEY_DEF("C-w", 0, 0, TB_KEY_CTRL_W)
MLE_KEY_DEF("C-x", 0, 0, TB_KEY_CTRL_X)
MLE_KEY_DEF("C-y", 0, 0, TB_KEY_CTRL_Y)
MLE_KEY_DEF("C-z", 0, 0, TB_KEY_CTRL_Z)
MLE_KEY_DEF("escape", 0, 0, TB_KEY_ESC)
MLE_KEY_DEF("C-[", 0, 0, TB_KEY_CTRL_LSQ_BRACKET)
MLE_KEY_DEF("C-3", 0, 0, TB_KEY_CTRL_3)
MLE_KEY_DEF("C-4", 0, 0, TB_KEY_CTRL_4)
MLE_KEY_DEF("C-\\", 0, 0, TB_KEY_CTRL_BACKSLASH)
MLE_KEY_DEF("C-5", 0, 0, TB_KEY_CTRL_5)
MLE_KEY_DEF("C-]", 0, 0, TB_KEY_CTRL_RSQ_BRACKET)
MLE_KEY_DEF("C-6", 0, 0, TB_KEY_CTRL_6)
MLE_KEY_DEF("C-7", 0, 0, TB_KEY_CTRL_7)
MLE_KEY_DEF("C-/", 0, 0, TB_KEY_CTRL_SLASH)
MLE_KEY_DEF("C-_", 0, 0, TB_KEY_CTRL_UNDERSCORE)
MLE_KEY_DEF("space", 0, 0, TB_KEY_SPACE)
MLE_KEY_DEF("comma", 0, 44, 0)
MLE_KEY_DEF("backspace2", 0, 0, TB_KEY_BACKSPACE2)
MLE_KEY_DEF("C-8", 0, 0, TB_KEY_CTRL_8)
